import logging

# we need to explicitly set a handler for the logging module to be happy
handler = logging.StreamHandler()
logging.getLogger("ossapi").addHandler(handler)

from oauthlib.oauth2 import AccessDeniedError, TokenExpiredError
from oauthlib.oauth2.rfc6749.errors import InsufficientScopeError

from ossapi.encoder import ModelEncoder, serialize_model
from ossapi.enums import (
    Availability,
    BeatmapDiscussionPostSort,
    BeatmapPackType,
    BeatmapPackUserCompletionData,
    BeatmapsetDiscussionVote,
    BeatmapsetDiscussionVoteSort,
    BeatmapsetEventType,
    BeatmapsetSearchCategory,
    BeatmapsetSearchExplicitContent,
    BeatmapsetSearchGenre,
    BeatmapsetSearchLanguage,
    BeatmapsetSearchMode,
    BeatmapsetSearchSort,
    BeatmapsetStatus,
    ChangelogSearch,
    CommentableType,
    CommentSort,
    Country,
    Cover,
    Covers,
    EventAchivement,
    EventBeatmap,
    EventBeatmapset,
    EventsSort,
    EventUser,
    Failtimes,
    ForumPollText,
    ForumPollTitle,
    ForumPostBody,
    ForumTopicSort,
    GameMode,
    GithubUser,
    GroupDescription,
    Hype,
    Kudosu,
    KudosuGiver,
    KudosuPost,
    KudosuVote,
    MatchEventType,
    MessageType,
    MultiplayerScoresSort,
    NewsPostKey,
    NewsSearch,
    Nomination,
    Nominations,
    ProfileBanner,
    RankHighest,
    RankHistory,
    Ranking,
    RankingFilter,
    RankingType,
    ReviewsConfig,
    RoomCategory,
    RoomSearchMode,
    RoomType,
    ScoreType,
    SearchMode,
    Statistics,
    UserAccountHistory,
    UserBadge,
    UserBeatmapType,
    UserGradeCounts,
    UserGroup,
    UserLevel,
    UserLookupKey,
    UserMonthlyPlaycount,
    UserPage,
    UserProfileCustomization,
    UserReplaysWatchedCount,
    Variant,
    Weight,
)
from ossapi.mod import Mod
from ossapi.models import (
    Beatmap,
    BeatmapCompact,
    BeatmapPack,
    BeatmapPacks,
    BeatmapPlaycount,
    BeatmapScores,
    Beatmapset,
    BeatmapsetCompact,
    BeatmapsetDiscussionPosts,
    BeatmapsetDiscussions,
    BeatmapsetDiscussionVotes,
    BeatmapsetSearchResult,
    BeatmapUserScore,
    Build,
    ChangelogListing,
    CommentBundle,
    CreatePMResponse,
    Cursor,
    Event,
    Events,
    ForumPoll,
    ForumTopicAndPosts,
    KudosuHistory,
    Match,
    Matches,
    MatchEvent,
    MatchEventDetail,
    MatchGame,
    MatchResponse,
    ModdingHistoryEventsBundle,
    MultiplayerScores,
    Rankings,
    Room,
    RoomLeaderboard,
    RoomLeaderboardScore,
    RoomLeaderboardUserScore,
    RoomPlaylistItem,
    RoomPlaylistItemMod,
    Score,
    ScoreMatchInfo,
    ScoringType,
    Search,
    Spotlight,
    Spotlights,
    StatisticsVariant,
    TeamType,
    User,
    UserCompact,
    WikiPage,
    _Event,
)
from ossapi.ossapi import (
    APIException,
    InvalidKeyException,
    OssapiV1,
    ReplayUnavailableException,
)
from ossapi.ossapiv2 import Domain, Grant, Ossapi, Scope
from ossapi.ossapiv2_async import OssapiAsync
from ossapi.replay import Replay

__version__ = "5.3.0"

__all__ = [
    # OssapiV1
    "OssapiV1",
    "ReplayUnavailableException",
    "InvalidKeyException",
    "APIException",
    # OssapiV2 core
    "Ossapi",
    "OssapiAsync",
    "Grant",
    "Scope",
    "Domain",
    # OssapiV2 models
    "Beatmap",
    "BeatmapCompact",
    "BeatmapUserScore",
    "ForumTopicAndPosts",
    "Search",
    "CommentBundle",
    "Cursor",
    "Score",
    "BeatmapsetSearchResult",
    "ModdingHistoryEventsBundle",
    "User",
    "Rankings",
    "BeatmapScores",
    "KudosuHistory",
    "Beatmapset",
    "BeatmapPlaycount",
    "Spotlight",
    "Spotlights",
    "WikiPage",
    "_Event",
    "Event",
    "BeatmapsetDiscussionPosts",
    "Build",
    "ChangelogListing",
    "MultiplayerScores",
    "BeatmapsetDiscussionVotes",
    "CreatePMResponse",
    "BeatmapsetDiscussions",
    "UserCompact",
    "BeatmapsetCompact",
    "ForumPoll",
    "Room",
    "RoomPlaylistItem",
    "RoomPlaylistItemMod",
    "RoomLeaderboardScore",
    "RoomLeaderboardUserScore",
    "RoomLeaderboard",
    "Match",
    "Matches",
    "MatchResponse",
    "ScoreMatchInfo",
    "MatchGame",
    "MatchEventDetail",
    "MatchEvent",
    "StatisticsVariant",
    "Events",
    "BeatmapPack",
    "BeatmapPacks",
    # OssapiV2 enums
    "GameMode",
    "ScoreType",
    "RankingFilter",
    "RankingType",
    "UserBeatmapType",
    "BeatmapDiscussionPostSort",
    "UserLookupKey",
    "BeatmapsetEventType",
    "CommentableType",
    "CommentSort",
    "ForumTopicSort",
    "SearchMode",
    "MultiplayerScoresSort",
    "BeatmapsetDiscussionVote",
    "BeatmapsetDiscussionVoteSort",
    "BeatmapsetStatus",
    "MessageType",
    "BeatmapsetSearchCategory",
    "BeatmapsetSearchMode",
    "BeatmapsetSearchExplicitContent",
    "BeatmapsetSearchLanguage",
    "BeatmapsetSearchGenre",
    "NewsPostKey",
    "BeatmapsetSearchSort",
    "RoomType",
    "RoomCategory",
    "RoomSearchMode",
    "MatchEventType",
    "ScoringType",
    "TeamType",
    "Variant",
    "EventsSort",
    "NewsSearch",
    "RankHighest",
    "Weight",
    "Statistics",
    "Availability",
    "Hype",
    "Nominations",
    "Nomination",
    "Kudosu",
    "KudosuGiver",
    "KudosuPost",
    "KudosuVote",
    "EventUser",
    "EventBeatmap",
    "EventBeatmapset",
    "EventAchivement",
    "GithubUser",
    "ChangelogSearch",
    "ForumPostBody",
    "ForumPollText",
    "ForumPollTitle",
    "ReviewsConfig",
    "UserMonthlyPlaycount",
    "UserPage",
    "UserLevel",
    "UserGradeCounts",
    "UserReplaysWatchedCount",
    "UserProfileCustomization",
    "RankHistory",
    "Covers",
    "UserGroup",
    "GroupDescription",
    "UserBadge",
    "UserAccountHistory",
    "ProfileBanner",
    "Cover",
    "Country",
    "Ranking",
    "Failtimes",
    "BeatmapPackType",
    "BeatmapPackUserCompletionData",
    # OssapiV2 exceptions
    "AccessDeniedError",
    "TokenExpiredError",
    "InsufficientScopeError",
    # misc
    "Mod",
    "Replay",
    "__version__",
    "ModelEncoder",
    "serialize_model",
]
